@@ -128,8 +128,8 @@ class Task(BaseModel):
             self.status,
             self.target_system,
             self.job_info.module + '.' + self.job_info.callback,
+            self.job_info.args + self.job_info.pydantic_args,
             {**self.job_info.kwargs, **self.job_info.pydantic_kwargs},
-            self.job_info.kwargs.update(self.job_info.pydantic_kwargs),
         )
 
     @classmethod
@@ -284,7 +284,8 @@ class ScheduleThread(threading.Thread):
     def listen_job_scheduled(self, event: JobEvent):
         logger.debug("listen_job_scheduled")
         task = self._get_task_by_id(int(event.job_id))
-        task.update(status=TaskState.scheduled)
+        job = self.scheduler.get_job(event.job_id)
+        task.update(status=TaskState.scheduled, job=job)
 
     def listen_execution_start(self, event: JobSubmissionEvent):
         logger.debug("listen_execution_start")
